=== modified file 'plugin/slave/docs/index.rst'
--- plugin/slave/docs/index.rst	2011-03-02 18:47:07 +0000
+++ plugin/slave/docs/index.rst	2011-03-07 21:42:32 +0000
@@ -14,9 +14,8 @@
 -------------
 
 Most of the options that can be used to control the replication slave plugin
-can only be given in a configuration file. The only exception is the
-:option:`--slave.config-file` option which designates the location of this configuration
-file.
+can only be given in a configuration file. The only exceptions are the
+:option:`--slave.config-file` and :option:`--slave.max-commit-id` options.
 
 .. program:: drizzled
 
@@ -29,6 +28,20 @@
    file. The relative path used by plugins is within the :option:`--datadir`
    directory, so a full path is recommended.
 
+.. option:: --slave.max-commit-id=arg
+
+   Manually set the maximum commit ID the slave is assumed to have retrieved
+   from the master. This value will be used by the slave to determine where
+   to begin retrieving replication messages from the master transaction log.
+   This option can be used to provision a new slave machine by setting it to
+   the value output from the drizzledump client when used with the
+   --single-transaction option.
+
+   This value is not allowed to be set via the configuration file since
+   you would normally only set it once on initial slave startup. This
+   eliminates the possibility of forgetting to delete it from the configuration
+   file for subsequent slave restarts.
+
 The options below are read from the configuration file.
 
 .. confval:: master-host

=== modified file 'plugin/slave/module.cc'
--- plugin/slave/module.cc	2011-02-17 14:20:50 +0000
+++ plugin/slave/module.cc	2011-03-07 21:42:32 +0000
@@ -45,6 +45,8 @@
   const module::option_map &vm= context.getOptions();
 
   ReplicationSlave *slave= new ReplicationSlave(vm["config-file"].as<string>());
+  if (vm.count("max-commit-id"))
+    slave->setMaxCommitId(vm["max-commit-id"].as<uint64_t>());
   context.add(slave);
   return 0;
 }
@@ -54,6 +56,9 @@
   context("config-file",
           po::value<string>()->default_value(DEFAULT_SLAVE_CFG_FILE.string()),
           N_("Path to the slave configuration file"));
+  context("max-commit-id",
+          po::value<uint64_t>(),
+          N_("Value to use as the maximum commit ID stored on the slave"));
 }
 
 } /* namespace slave */

=== modified file 'plugin/slave/queue_producer.h'
--- plugin/slave/queue_producer.h	2011-03-07 15:57:02 +0000
+++ plugin/slave/queue_producer.h	2011-03-08 06:28:23 +0000
@@ -91,6 +91,11 @@
     _seconds_between_reconnects= seconds;
   }
 
+  void setMaxCommitId(uint64_t value)
+  {
+    _saved_max_commit_id= value;
+  }
+
 private:
   /** Number of seconds to sleep between checking queue for messages */
   uint32_t _check_interval;

=== modified file 'plugin/slave/replication_slave.h'
--- plugin/slave/replication_slave.h	2011-02-17 14:20:50 +0000
+++ plugin/slave/replication_slave.h	2011-03-07 21:42:32 +0000
@@ -60,6 +60,22 @@
     return _error;
   }
 
+  /**
+   * Set the initial value for the slave's maximum commit ID.
+   *
+   * This value basically determines where to start retrieving events from
+   * the master. Normally this is computed automatically based on the
+   * contents of the queue and/or the last applied commit ID. This allows
+   * us to override those values and start from another point. E.g., new
+   * slave provisioning or skipping a trouble statement.
+   *
+   * @param[in] value The commit ID value.
+   */
+  void setMaxCommitId(uint64_t value)
+  {
+    _producer.setMaxCommitId(value);
+  }
+
 private:
   std::string _config_file;
   std::string _error;

